==> downloads.html?file=gigkalender_v1.2.61_069_update-63_076.zip: gigkalender/gigkalender.ini.php <==
<?php

  # Change these variables BEFORE the installation and later if required:
  # Diese Variablen VOR der Installation anpassen und später nach Bedarf:
    $db_name = "xxx...";
    $db_host = "xxx...";
    $db_user = "xxx...";
    $db_password = "xxx...";
    $prefix = "gigkalender_";
    $GigKalenderPath = "http://www.my-domain.xyz/gigkalender/";

  # These variables can be changed at ANY TIME to configure the GigKalender:
  # Diese Variablen können JEDERZEIT verändert werden um den GigKalender zu konfigurieren:
    $CharsCalenderListFields = 22; // 22
    $CharsGuestbookListFields = 36; // 36
    $SetupBackendDateFormat = 'Y-m-d'; // Y-m-d -> www.php.net/date
    $SetupBackendTimeFormat = 'H:i'; // H:i -> www.php.net/date
    $SetupFrontendCalendarDateFormat = 'Y-m-d'; // Y-m-d -> www.php.net/date
    $SetupFrontendCalendarGigDetailsDateFormat = 'Y-m-d'; // Y-m-d -> www.php.net/date
    $SetupFrontendNewsDateFormat = 'Y-m-d - H:i'; // Y-m-d - H:i -> www.php.net/date
    $SetupFrontendGuestbookDateFormat = 'Y-m-d - H:i'; // Y-m-d - H:i -> www.php.net/date
    $SetupFrontendCalendarCurrentMonthLimitFuture = 12; // 12 Month
    $SetupFrontendCalendarCurrentMonthLimitPast = 6; // 6 Month
    //$SetupBackendFirstDayOfWeek = 'Monday'; // Monday
    //$SetupFrontendFirstDayOfWeek = 'Monday'; // Monday
    
    $SetupFrontendCalendarCurrentMonthShowPastGigs = true; // true, false
    $SetupFrontendCalendarGigDetailsShowEmptyAttributes = false; // true, false
    $SetupWriteGuestbookSpamLog = false; // true, false
    $SetupUseCache = true; // true, false
    
    $SetupGalleryURL = '';
    $SetupGuestbookURL = '';
    $SetupGuestbookFormURL = '';
    $SetupGuestbookEmailURL = '';
    $SetupFrontendCalendarURL = '';
    $SetupFrontendCalendarGigDetailsURL = '';
    $SetupFrontendCalendarCurrentMonthURL = '';

  # If required change these variables ONLY BEFORE the installation:
  # Diese Variablen bei Bedarf NUR VOR der Installation ändern:
    $CharsGigCountry = 3;
    $CharsGigDistrict = 3;
    $CharsGigPostcode = 10;
    $CharsGigCity = 40;
    $CharsGigEvent = 40;
    $CharsGigEventURL = 255;
    $CharsGigVenue = 40;
    $CharsGigVenueURL = 255;
    $CharsGigOrganizer = 40;
    $CharsGigOrganizerURL = 255;
    $CharsGigLineup = 40;
    $CharsGigVisitors = 6;
    $CharsGigStageBuilding = 40;
    $CharsGigBeginning = 40;
    $CharsGigDuration = 40;
    $CharsGigEnding = 40;
    $CharsGigStatus = 20;
    $CharsGigArtist = 50;
    $CharsGigArtistURL = 255;
    $CharsGigEntranceFee = 40;
    $CharsNewsTitle = 50;
    $CharsUserName = 20;
    $CharsSetupNewsChannelTitle = 50;
    $CharsSetupNewsChannelURL = 255;
    $CharsSetupNewsChannelDescription = 255;
    $CharsSetupNewsChannelLanguage = 10;
    $CharsSetupNewsChannelCopyright = 50;
    $CharsMenuItemName = 20;
    $CharsMenuItemFile = 20;
    $MinUserPasswordChars = 4;

  # NEVER change these variables:
  # Diese Variablen NIEMALS ändern:
    $db = mysql_connect ($db_host, $db_user, $db_password)
          or die ('<span class="Fehlermeldung">ERROR: No connection to database! ('.mysql_error().')</span><br />');
    mysql_query('SET NAMES utf8'); // utf8, latin1
    mysql_query('SET CHARACTER SET utf8'); // utf8, latin1
    
    define ("PATH", $GigKalenderPath);
    $GigKalenderVersion = 'v1.2.63_076';
    $allGigAttributes = "GigArtist, GigBeginning, GigDateOfAdding, GigDateOfLastEdit, GigNotes, GigDuration, GigEnding, GigEntranceFee, GigIsPrivate, GigLineup, GigLocation, GigEvent, GigOrganizer, GigPublish, GigStageBuilding, GigStatus, GigVenue, GigVisitors";
    $allBackendCalenderFormAttributes = "GigCountry, GigDistrict, GigPostalCode, GigCity, GigEvent, GigEventURL, GigEntranceFee, GigVenue, GigVenueURL, GigOrganizer, GigOrganizerURL, GigArtist, GigArtistURL, GigLineup, GigVisitors, GigStageBuilding, GigBeginning, GigDuration, GigEnding, GigNotes";
    $allFrontendAttributes = "GigLocation, GigEvent, GigEntranceFee, GigVenue, GigOrganizer, GigArtist, GigLineup, GigVisitors, GigStageBuilding, GigDuration, GigEnding, GigNotes, GigStatus, GigIsPrivate, GigDateOfAdding, GigDateOfLastEdit";
    $allFrontendDetailAttributes = "GigLocation, GigEvent, GigEntranceFee, GigVenue, GigOrganizer, GigArtist, GigLineup, GigVisitors, GigStageBuilding, GigBeginning, GigDuration, GigEnding, GigNotes, GigStatus, GigIsPrivate, GigDateOfAdding, GigDateOfLastEdit";
    $StandardUserBackendCalenderListCols = "GigBeginning, GigArtist, GigLocation, GigEvent, GigVenue, GigLineup, GigStageBuilding, GigNotes, GigIsPrivate, GigPublish";
    $StandardFrontendAttributes = "GigLocation, GigArtist, GigVenue, GigEvent";
    $StandardFrontendDetailAttributes = "GigLocation, GigEvent, GigEntranceFee, GigVenue, GigArtist, GigIsPrivate";
    $ShowCMS = 0; // 0, 1
    $ContentPath = "../content/"; // frontend/content/
    $PossibleImageExtensions = array ('jpg','png','gif','jpeg','JPG');
    $PossibleTextExtensions = array ('txt','php','html','htm');
?>

==> downloads.html?file=gigkalender_v1.2.66_014_update-72_002.zip: gigkalender/gigkalender.ini.php <==
<?php

  # Change these variables BEFORE the installation and later if required:
  # Diese Variablen VOR der Installation anpassen und später nach Bedarf:
    $db_name = "xxx...";
    $db_host = "xxx...";
    $db_user = "xxx...";
    $db_password = "xxx...";
    $prefix = "gigkalender_";
    $GigKalenderPath = "http://www.my-domain.xyz/gigkalender/";

  # These variables can be changed at ANY TIME to configure the GigKalender:
  # Diese Variablen können JEDERZEIT verändert werden um den GigKalender zu konfigurieren:
    $CharsCalenderListFields = 22; // 22
    $CharsGuestbookListFields = 36; // 36
    $SetupBackendDateFormat = 'Y-m-d'; // Y-m-d -> www.php.net/date
    $SetupBackendTimeFormat = 'H:i'; // H:i -> www.php.net/date
    $SetupFrontendTimeFormat = 'H:i'; // H:i -> www.php.net/date
    $SetupFrontendCalendarDateFormat = 'Y-m-d'; // Y-m-d -> www.php.net/date
    $SetupFrontendCalendarGigDetailsDateFormat = 'Y-m-d'; // Y-m-d -> www.php.net/date
    $SetupFrontendCalendarCurrentMonthLimitFuture = 12; // 12 Month
    $SetupFrontendCalendarCurrentMonthLimitPast = 6; // 6 Month
    $SetupFrontendGuestbookDateFormat = 'Y-m-d - H:i'; // Y-m-d - H:i -> www.php.net/date
    $SetupFrontendNewsDateFormat = 'Y-m-d - H:i'; // Y-m-d - H:i -> www.php.net/date
    $SetupFrontendGallerySorting = 'DESC'; // DESC, ASC
    $SetupFrontendGalleryImagesWidth = 760; // 760
    $SetupFrontendGalleryImagesInterlacing = TRUE; // TRUE
    //$SetupFrontendGalleryImageFormat = 'jpeg'; // auto, jpeg, pgn
    $SetupFrontendGalleryJpegQuality = 88; // 88
    $SetupFrontendGalleryPNGQuality = 1; // 1, Compression level: from 0 (no compression) to 9
    $SetupFrontendGalleryThumbnailsWidth = 120; // 120

    $SetupCalendarLocationShowCountry = true; // true, false
    $SetupCalendarLocationShowDistrict = true;  // true, false
    $SetupCalendarLocationShowPostalCode = true; // true, false
    $SetupCalendarLocationShowCity = true; // true, false
    
    //$SetupBackendFirstDayOfWeek = 'Monday'; // Monday
    //$SetupFrontendFirstDayOfWeek = 'Monday'; // Monday
    
    $SetupFrontendCalendarCurrentMonthShowPastGigs = true; // true, false
    $SetupFrontendCalendarGigDetailsShowEmptyAttributes = false; // false, true
    $SetupWriteGuestbookSpamLog = false; // false, true
    $SetupUseCache = true; // true, false
    
    $SetupGalleryURL = '';
    $SetupGuestbookURL = '';
    $SetupGuestbookFormURL = '';
    $SetupGuestbookEmailURL = '';
    $SetupFrontendCalendarURL = '';
    $SetupFrontendCalendarGigDetailsURL = '';
    $SetupFrontendCalendarCurrentMonthURL = '';

  # If required change these variables ONLY BEFORE the installation:
  # Diese Variablen bei Bedarf NUR VOR der Installation ändern:
    $CharsGigCountry = 3;
    $CharsGigDistrict = 3;
    $CharsGigPostcode = 10;
    $CharsGigCity = 40;
    $CharsGigEvent = 40;
    $CharsGigEventURL = 255;
    $CharsGigVenue = 40;
    $CharsGigVenueURL = 255;
    $CharsGigOrganizer = 40;
    $CharsGigOrganizerURL = 255;
    $CharsGigLineup = 40;
    $CharsGigVisitors = 6;
    $CharsGigStageBuilding = 40;
    $CharsGigBeginning = 40;
    $CharsGigDuration = 40;
    $CharsGigEnding = 40;
    $CharsGigStatus = 20;
    $CharsGigArtist = 50;
    $CharsGigArtistURL = 255;
    $CharsGigEntranceFee = 40;
    $CharsNewsTitle = 50;
    $CharsUserName = 20;
    $CharsSetupNewsChannelTitle = 50;
    $CharsSetupNewsChannelURL = 255;
    $CharsSetupNewsChannelDescription = 255;
    $CharsSetupNewsChannelLanguage = 10;
    $CharsSetupNewsChannelCopyright = 50;
    $CharsMenuItemName = 20;
    $CharsMenuItemFile = 20;
    $MinUserPasswordChars = 4;

  # NEVER change these variables:
  # Diese Variablen NIEMALS ändern:
    $db = mysqli_connect ($db_host, $db_user, $db_password)
          or die ('<span class="ErrorMessage">ERROR: No connection to database! ('.mysqli_error($db).')</span><br />');
    mysqli_select_db($db, $db_name);
    //mysqli_query($db, 'SET NAMES utf8'); // utf8, latin1
    //mysqli_character_set_name($db, "utf8");
    //mysqli_query($db, 'SET CHARACTER SET utf8'); // utf8, latin1
    mysqli_set_charset($db, "utf8");
    
    $GigKalenderPath = $GigKalenderPath.'/';
    define ("PATH", $GigKalenderPath);
    include_once('includes/version.php');
    $allGigAttributes = "GigArtist, GigBeginning, GigDateOfAdding, GigDateOfLastEdit, GigNotes, GigDuration, GigEnding, GigEntranceFee, GigIsPrivate, GigLineup, GigLocation, GigEvent, GigOrganizer, GigPublish, GigStageBuilding, GigStatus, GigVenue, GigVisitors";
    $allBackendCalenderFormAttributes = "GigCountry, GigDistrict, GigPostalCode, GigCity, GigEvent, GigEventURL, GigEntranceFee, GigVenue, GigVenueURL, GigOrganizer, GigOrganizerURL, GigArtist, GigArtistURL, GigLineup, GigVisitors, GigStageBuilding, GigBeginning, GigDuration, GigEnding, GigNotes";
    $allFrontendAttributes = "GigLocation, GigEvent, GigEntranceFee, GigVenue, GigOrganizer, GigArtist, GigLineup, GigVisitors, GigStageBuilding, GigDuration, GigEnding, GigNotes, GigStatus, GigIsPrivate, GigDateOfAdding, GigDateOfLastEdit, GigDetailsLink";
    $allFrontendDetailAttributes = "GigLocation, GigEvent, GigEntranceFee, GigVenue, GigOrganizer, GigArtist, GigLineup, GigVisitors, GigStageBuilding, GigBeginning, GigDuration, GigEnding, GigNotes, GigStatus, GigIsPrivate, GigDateOfAdding, GigDateOfLastEdit";
    $StandardUserBackendCalenderListCols = "GigBeginning, GigArtist, GigLocation, GigEvent, GigVenue, GigLineup, GigStageBuilding, GigNotes, GigIsPrivate, GigPublish";
    $StandardFrontendAttributes = "GigLocation, GigArtist, GigVenue, GigEvent, GigDetailsLink";
    $StandardFrontendDetailAttributes = "GigLocation, GigEvent, GigEntranceFee, GigVenue, GigArtist, GigIsPrivate";
    $ShowCMS = 0; // 0, 1
    $ContentPath = "../content/"; // frontend/content/
    $PossibleImageExtensions = array ('jpg','png','gif','jpeg','JPG');
    $PossibleTextExtensions = array ('txt','php','html','htm');
?>
